Product class

Constructors

Product({required String id, required String type, required String displayName, required String description, required double price, required String displayPrice, SubscriptionInfo? subscription})
Product.fromMap(Map<String, dynamic> map)
factory

Properties

description → String
final
displayName → String
final
displayPrice → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
price → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → SubscriptionInfo?
Properties and functionality specific to auto-renewable subscriptions.
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

autoRenewable → const String
consumable → const String
nonConsumable → const String
nonRenewable → const String