Status class

Constructors

Status({required String state, required Transaction? transaction, required RenewalInfo? renewalInfo})
Status.fromMap(Map map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
renewalInfo → RenewalInfo?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String
final
transaction → Transaction?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

expired → const String
inBillingRetryPeriod → const String
inGracePeriod → const String
revoked → const String
subscribed → const String