SubscriptionInfo class

Constructors

SubscriptionInfo({required SubscriptionOffer? introductoryOffer, required List<SubscriptionOffer> promotionalOffers, required String subscriptionGroupID, required SubscriptionPeriod subscriptionPeriod})
SubscriptionInfo.fromMap(Map map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
introductoryOffer → SubscriptionOffer?
An optional introductory offer that will automatically be applied if the user is eligible.
final
promotionalOffers → List<SubscriptionOffer>
An array of all the promotional offers configured for this subscription.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionGroupID → String
The group identifier for this subscription.
final
subscriptionPeriod → SubscriptionPeriod
The duration that this subscription lasts before auto-renewing.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited