SubscriptionOffer class

Constructors

SubscriptionOffer({required String? id, required String type, required double price, required String displayPrice, required SubscriptionPeriod period, required int periodCount, required String paymentMode})
SubscriptionOffer.fromMap(Map map)
factory

Properties

displayPrice → String
A localized string representation of price.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The promotional offer identifier.
final
paymentMode → String
How the user is charged for this offer.
final
period → SubscriptionPeriod
The duration that this offer lasts before auto-renewing or changing to standard subscription renewals.
final
periodCount → int
The number of periods this offer will renew for.
final
price → double
The discounted price that the offer provides in local currency.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of offer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited