SubscriptionPeriod class

Constructors

SubscriptionPeriod({required int value, required String unit})
SubscriptionPeriod.fromMap(Map map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → String
The unit of time that this period represents.
final
value → int
The number of units that the period represents.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

day → const String
month → const String
week → const String
year → const String