MethodChannelStorekit2 class

An implementation of Storekit2Platform that uses method channels.

Inheritance

Constructors

MethodChannelStorekit2()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionUpdates → Stream<Map<String, dynamic>>
no setteroverride

Methods

beginRefundRequest(int transactionId) → Future<String>
override
dispose() → void
override
getCurrentEntitlements() → Future<List<Transaction>>
override
getPlatformVersion() → Future<String?>
inherited
getProducts(List<String> productIds) → Future<List<Product>>
override
getSubscriptionStatus(String groupId) → Future<List<Status>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purchase(String appAccountToken, String productId) → Future<Transaction?>
override
restore() → Future<bool>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited