Storekit2Platform class abstract

Inheritance
  • Object
  • PlatformInterface
  • Storekit2Platform
Implementers

Constructors

Storekit2Platform()
Constructs a Storekit2Platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionUpdates → Stream<Map<String, dynamic>>
no setter

Methods

beginRefundRequest(int transactionId) → Future<String>
dispose() → void
getCurrentEntitlements() → Future<List<Transaction>>
getPlatformVersion() → Future<String?>
getProducts(List<String> productIds) → Future<List<Product>>
getSubscriptionStatus(String groupId) → Future<List<Status>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purchase(String appAccountToken, String productId) → Future<Transaction?>
restore() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ Storekit2Platform
The default instance of Storekit2Platform to use.
getter/setter pair